summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/RGLed.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/kdeext/RGLed.cpp')
-rw-r--r--src/gui/kdeext/RGLed.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/gui/kdeext/RGLed.cpp b/src/gui/kdeext/RGLed.cpp
index fbadb95..a928ee5 100644
--- a/src/gui/kdeext/RGLed.cpp
+++ b/src/gui/kdeext/RGLed.cpp
@@ -59,7 +59,7 @@
*
* Revision 1.19 2001/08/08 14:35:12 hausmann
* - removed empty KActionCollection::childEvent
* - added tqsizeHint() and tqminimumSizeHint() methods to KLed, as advised by
* Rik in the comment in kled.h
* - removed unused mousePressEvent, mouseMoveEvent and mouseReleaseEvent
* handlers from KPassDlg
@@ -160,7 +160,7 @@ KLed::KLed(TQWidget *parent, const char *name)
: TQWidget( parent, name),
led_state(On),
led_look(Raised),
- led_tqshape(Circular)
+ led_shape(Circular)
{
TQColor col(green);
d = new KLed::KLedPrivate;
@@ -177,7 +177,7 @@ KLed::KLed(const TQColor& col, TQWidget *parent, const char *name)
: TQWidget( parent, name),
led_state(On),
led_look(Raised),
- led_tqshape(Circular)
+ led_shape(Circular)
{
d = new KLed::KLedPrivate;
d->dark_factor = 300;
@@ -190,11 +190,11 @@ KLed::KLed(const TQColor& col, TQWidget *parent, const char *name)
}
KLed::KLed(const TQColor& col, KLed::State state,
- KLed::Look look, KLed::Shape tqshape, TQWidget *parent, const char *name )
+ KLed::Look look, KLed::Shape shape, TQWidget *parent, const char *name )
: TQWidget(parent, name),
led_state(state),
led_look(look),
- led_tqshape(tqshape)
+ led_shape(shape)
{
d = new KLed::KLedPrivate;
d->dark_factor = 300;
@@ -202,7 +202,7 @@ KLed::KLed(const TQColor& col, KLed::State state,
d->off_map = 0;
d->on_map = 0;
- //setShape(tqshape);
+ //setShape(shape);
setColor(col);
}
@@ -223,7 +223,7 @@ KLed::paintEvent(TQPaintEvent *)
t.start();
for (int i = 0; i < rounds; i++) {
#endif
- switch (led_tqshape) {
+ switch (led_shape) {
case Rectangular:
switch (led_look) {
case Sunken :
@@ -298,7 +298,7 @@ KLed::paintFlat() // paint a ROUND FLAT led lamp
brush.setColor( color );
pen.setWidth( 1 );
- color = tqcolorGroup().dark();
+ color = colorGroup().dark();
pen.setColor( color ); // Set the pen accordingly
paint.setPen( pen ); // Select pen for drawing
@@ -386,7 +386,7 @@ KLed::paintRound() // paint a ROUND RAISED led lamp
// avoid that the border can be erased by the bright spot of the LED
pen.setWidth( 1 );
- color = tqcolorGroup().dark();
+ color = colorGroup().dark();
pen.setColor( color ); // Set the pen accordingly
paint.setPen( pen ); // Select pen for drawing
brush.setStyle( Qt::NoBrush ); // Switch off the brush
@@ -509,11 +509,11 @@ KLed::paintSunken() // paint a ROUND SUNKEN led lamp
brush.setStyle( Qt::NoBrush ); // Switch off the brush
paint.setBrush( brush ); // This avoids filling of the ellipse
// Set the initial color value to tqcolorGroup().light() (bright) and start
// drawing the shadow border at 45� (45*16 = 720).
int angle = -720;
- color = tqcolorGroup().light();
+ color = colorGroup().light();
for ( int arc = 120; arc < 2880; arc += 240 )
{
@@ -612,9 +612,9 @@ KLed::state() const
}
KLed::Shape
-KLed::tqshape() const
+KLed::shape() const
{
- return led_tqshape;
+ return led_shape;
}
TQColor
@@ -649,8 +649,8 @@ KLed::toggleState()
void
KLed::setShape(KLed::Shape s)
{
- if (led_tqshape != s) {
- led_tqshape = s;
+ if (led_shape != s) {
+ led_shape = s;
update();
}
}
@@ -713,13 +713,13 @@ KLed::off()
}
TQSize
-KLed::tqsizeHint() const
+KLed::sizeHint() const
{
return TQSize(16, 16);
}
TQSize
-KLed::tqminimumSizeHint() const
+KLed::minimumSizeHint() const
{
return TQSize(16, 16 );
}
@@ -59,7 +59,7 @@
* Revision 1.19 2001/08/08 14:35:12 hausmann
* - removed empty KActionCollection::childEvent
- * - added tqsizeHint() and tqminimumSizeHint() methods to KLed, as advised by
+ * - added sizeHint() and minimumSizeHint() methods to KLed, as advised by
* Rik in the comment in kled.h
* - removed unused mousePressEvent, mouseMoveEvent and mouseReleaseEvent
@@ -509,11 +509,11 @@ KLed::paintSunken() // paint a ROUND SUNKEN led lamp
brush.setStyle( Qt::NoBrush ); // Switch off the brush
paint.setBrush( brush ); // This avoids filling of the ellipse
- // Set the initial color value to tqcolorGroup().light() (bright) and start
+ // Set the initial color value to colorGroup().light() (bright) and start
// drawing the shadow border at 45� (45*16 = 720).
int angle = -720;